package net.sf.basedb.examples.extensions.toolbar;

import net.sf.basedb.clients.web.extensions.JspContext;
import net.sf.basedb.clients.web.extensions.toolbar.ButtonAction;
import net.sf.basedb.clients.web.extensions.toolbar.ButtonBean;
import net.sf.basedb.clients.web.extensions.toolbar.FixedButtonFactory;
import net.sf.basedb.core.BasicItem;
import net.sf.basedb.core.Nameable;
import net.sf.basedb.core.data.BasicData;
import net.sf.basedb.core.data.NameableData;
import net.sf.basedb.core.plugin.GuiContext;
import net.sf.basedb.util.extensions.InvokationContext;

/**
	Example toolbar button factory that creates a "More info" button
	on all single-item pages that opens a dialog that displays some
	trivial information about the item.
	<p>
	This factory builds on the {@link FixedButtonFactory}
	but uses a simple template patten in the {@link #getOnClick()} 
	($TYPE and $ID are replaced
	with the item type and item id) and {@link #getTooltip()}
	($NAME is replaced by the name of the item).
	
	@author nicklas
*/
public class InfoButtonFactory 
	extends FixedButtonFactory
{

	public InfoButtonFactory()
	{}
	
	@Override
	public ButtonAction[] getActions(InvokationContext context) 
	{
		ButtonAction[] actions = null;
		Object item = context.getClientContext().getCurrentItem();
		JspContext jspContext = (JspContext)context.getClientContext();
		GuiContext guiContext = jspContext.getGuiContext();
		String ID = null;
		String TYPE = guiContext == null ? null : guiContext.getItem().name();
		String name = null;
		if (item instanceof BasicItem)
		{
			BasicItem bItem = (BasicItem)item;
			ID = Integer.toString(bItem.getId());
			TYPE = bItem.getType().name();
			name = (item instanceof Nameable) ?
				((Nameable)item).getName() : item.toString();
				
		}
		else if (item instanceof BasicData)
		{
			BasicData bData = (BasicData)item;
			ID = Integer.toString(bData.getId());
			name = (item instanceof NameableData) ?
					((NameableData)item).getName() : item.toString();
		}
		String onClick = getOnClick();
		if (onClick != null)
		{
			if (ID != null) onClick = onClick.replace("$ID", ID);
			onClick = onClick.replace("$TYPE", TYPE);
		}
		String tooltip = getTooltip();
		if (tooltip != null)
		{
			if (name != null) tooltip = tooltip.replace("$NAME", name);
		}
		ButtonBean action = new ButtonBean();
		action.setClazz(getClazz());
		action.setEnabled(isEnabled());
		action.setIcon(getIcon());
		action.setId(getId());
		action.setOnClick(onClick);
		action.setStyle(getStyle());
		action.setTitle(getTitle());
		action.setTooltip(tooltip);
		action.setVisible(isVisible());
		actions = new ButtonAction[] { action };
		return actions;
	}

}
